import { FC, PropsWithoutRef, HTMLAttributes, PropsWithRef, CSSProperties, RefCallback, PureComponent, PropsWithChildren, ReactNode, KeyboardEvent, ChangeEvent, Component, ComponentClass, FormEvent } from "react";
import { TimeData, CamelEventName } from "web-utility";
import { PaginationProps, ButtonProps, SpinnerProps, DropdownButtonProps, TableProps, ModalProps } from "react-bootstrap";
import { Map, LeafletEventHandlerFnMap } from "leaflet";
import { MapContainerProps, MarkerProps } from "react-leaflet";
import { Color } from "react-bootstrap/esm/types";
export type TimeDistanceProps = PropsWithoutRef<{
    className?: string;
    date: TimeData;
    unitWords?: Record<string, string>;
    beforeWord?: string;
    afterWord?: string;
}>;
export const TimeDistance: FC<TimeDistanceProps>;
export interface PaginationBarProps extends Omit<PaginationProps, 'onChange'> {
    currentPage?: number;
    pageCount: number;
    count?: number;
    onChange: (index: number) => any;
}
export const PaginationBar: FC<PaginationBarProps>;
export type IconProps = PropsWithRef<HTMLAttributes<HTMLSpanElement> & {
    name: string;
    size?: number;
}>;
export const Icon: FC<IconProps>;
export type AvatarProps = PropsWithoutRef<{
    style?: CSSProperties;
    className?: string;
    src?: string;
    size?: number;
}>;
export const Avatar: FC<AvatarProps>;
export type NameplateProps = PropsWithoutRef<{
    avatar: string;
    name: string;
}>;
export const Nameplate: FC<NameplateProps>;
export type TableSpinnerProps = PropsWithoutRef<{
    colSpan: number;
}>;
export const TableSpinner: FC<TableSpinnerProps>;
export type TypeEchoProps = PropsWithoutRef<{
    className?: string;
    text: string;
    intervals?: number;
}>;
type State = {
    echoed: string;
};
export class TypeEcho extends PureComponent<TypeEchoProps, State> {
    static displayName: string;
    state: Readonly<State>;
    init: RefCallback<HTMLPreElement>;
    render(): JSX.Element;
}
export type ClickBoundaryProps = PropsWithChildren<{
    className?: string;
    onInnerClick?: (event: MouseEvent) => any;
    onOuterClick?: (event: MouseEvent) => any;
}>;
export class ClickBoundary extends PureComponent<ClickBoundaryProps> {
    root: import("react").RefObject<HTMLDivElement>;
    switchClick: (event: MouseEvent) => void;
    componentDidMount(): void;
    componentWillUnmount(): void;
    render(): JSX.Element;
}
export type EdgePosition = 'top' | 'bottom' | 'left' | 'right';
type TouchHandler = (edge: EdgePosition) => any;
export interface ScrollBoundaryProps extends Partial<Record<EdgePosition, ReactNode>> {
    className?: string;
    onTouch: TouchHandler;
}
export const ScrollBoundary: FC<ScrollBoundaryProps>;
export interface SpinnerButtonProps extends ButtonProps, Pick<SpinnerProps, 'animation'> {
    loading?: boolean;
}
export const SpinnerButton: FC<SpinnerButtonProps>;
export type OptionProps = PropsWithChildren<{
    className?: string;
    style?: CSSProperties;
    value?: string;
}>;
export const Option: FC<OptionProps>;
export interface SelectProps extends OptionProps, Pick<DropdownButtonProps, 'variant' | 'menuVariant'> {
    onChange?: (value: string) => any;
    valueRender?: (value: string) => ReactNode;
}
export const Select: FC<SelectProps>;
export interface OptionItem {
    value?: any;
    label: string;
}
export interface FilterInputProps {
    name: string;
    required?: boolean;
    defaultValue?: OptionItem[];
    loadOptions?: (input: string) => Promise<OptionItem[]>;
}
interface _State1 {
    options: OptionItem[];
    values: OptionItem[];
}
export class FilterInput extends PureComponent<FilterInputProps, _State1> {
    static displayName: string;
    state: Readonly<_State1>;
    componentDidMount(): void;
    componentDidUpdate(lastProps: FilterInputProps, lastState: _State1): void;
    addOne(value: OptionItem): void;
    deleteOne(index: number): void;
    handleInput: (event: KeyboardEvent<HTMLInputElement>) => void;
    loadOptions: import("lodash").DebouncedFunc<() => Promise<void>>;
    render(): JSX.Element;
}
export type FilePickerProps = PropsWithoutRef<{
    accept: `${string}/${string}`;
    name: string;
    multiple?: boolean;
    required?: boolean;
    defaultValue?: string[];
}>;
interface _State2 {
    values: string[];
}
export class FilePicker extends PureComponent<FilePickerProps, _State2> {
    static displayName: string;
    state: Readonly<_State2>;
    componentDidMount(): void;
    componentDidUpdate(lastProps: FilePickerProps, lastState: _State2): void;
    addOne: ({ currentTarget: { files } }: ChangeEvent<HTMLInputElement>) => void;
    deleteOne(index: number): void;
    render(): JSX.Element;
}
export interface FileUploaderProps {
    value?: string;
    name: string;
    disabled?: boolean;
    onChange: Function;
}
interface FileUploaderState {
    file: string;
    fileName: string;
    isImage: boolean;
}
export class FileUploader extends Component<FileUploaderProps, FileUploaderState> {
    static displayName: string;
    state: {
        file: string;
        fileName: string;
        isImage: boolean;
    };
    componentDidMount(): void;
    change: ({ target: { files } }: ChangeEvent<HTMLInputElement>) => void;
    render(): JSX.Element;
}
export interface MultipleFileUploaderProps {
    name?: string;
    value?: string[];
    onChange: Function;
    onDeleteOne: Function;
}
export const MultipleFileUploader: FC<MultipleFileUploaderProps>;
export type EditorProps = PropsWithoutRef<{
    tools: Record<string, ComponentClass>;
    name: string;
    defaultValue: string;
}>;
interface _State3 {
    value: string;
}
export class Editor extends PureComponent<EditorProps, _State3> {
    static displayName: string;
    state: Readonly<_State3>;
    static getDerivedStateFromProps({ defaultValue }: EditorProps, { value }: _State3): _State3;
    save: () => Promise<void>;
    render(): JSX.Element;
}
export const parser: any;
export type EditorHTMLProps = PropsWithoutRef<{
    className?: string;
    data: string;
}>;
export const EditorHTML: FC<EditorHTMLProps>;
export interface Column<T> {
    key?: string;
    label: ReactNode | ((column: Column<T>) => ReactNode);
    summary?: ReactNode | ((column: Column<T>) => ReactNode);
    width?: number;
    render?: (params: T, index?: number) => ReactNode;
}
export interface IdeaTableProps<T> extends TableProps {
    rowKey?: keyof T | ((params: T) => string | number);
    noneNode?: ReactNode;
    loadingNode?: ReactNode;
    columns: Column<T>[];
    list: T[];
}
export class IdeaTable<T extends Record<string, any>> extends PureComponent<IdeaTableProps<T>> {
    static displayName: string;
    rowKeyOf(row: T): string | number | T[keyof T];
    renderRow: (row: T, index: number) => JSX.Element;
    renderEdge(field: 'label' | 'summary'): JSX.Element;
    render(): JSX.Element;
}
export interface IdeaInfoItem<T> {
    label: ReactNode | ((field: IdeaInfoItem<T>) => ReactNode);
    labelCol?: number;
    key?: string;
    render?: (params: T) => ReactNode;
}
export interface IdeaInfoProps<T> {
    className?: string;
    rows: IdeaInfoItem<T>[];
    data: T;
}
export const IdeaInfo: <T>({ rows, data, ...other }: IdeaInfoProps<T>) => JSX.Element;
export interface IdeaDialogProps extends Partial<Pick<SpinnerButtonProps, 'animation' | 'loading'> & Pick<ModalProps, 'className' | 'show' | 'size' | 'fullscreen' | 'centered' | 'scrollable' | 'contentClassName'>> {
    title: string;
    formId?: string;
    confirmText?: string;
    onConfirm?: () => any;
    cancelText?: string;
    onCancel?: () => any;
}
export const IdeaDialog: FC<IdeaDialogProps>;
export interface Base {
    id: number | string;
}
export interface IdeaFormItem<T> {
    key?: string;
    label: string;
    required?: boolean;
    disabled?: boolean;
    pattern?: string;
    tip?: string;
    show?: boolean;
    render?: (params: T) => ReactNode;
    onChange?: (event: ChangeEvent) => any;
}
export interface IdeaFormProps<T> {
    id?: string;
    className?: string;
    controlClassName?: string;
    labelCols?: number;
    controlCols?: number;
    submitText?: string;
    onSubmit?: (event: FormEvent<HTMLFormElement>) => void;
    resetText?: string;
    onReset?: (event: FormEvent<HTMLFormElement>) => void;
    rows: IdeaFormItem<T>[];
    data: T;
}
export const IdeaForm: <T extends Base>({ rows, data, labelCols, controlCols, className, controlClassName, submitText, resetText, ...other }: IdeaFormProps<T>) => JSX.Element;
interface _State4 {
    showPopover: boolean;
    popoverTarget: EventTarget;
}
export type IdeaPopoverProps = PropsWithChildren<{
    onShow?: () => any;
    title: string;
}>;
export class IdeaPopover extends PureComponent<IdeaPopoverProps, _State4> {
    static displayName: string;
    popoverRef: import("react").RefObject<HTMLDivElement>;
    state: {
        showPopover: boolean;
        popoverTarget: HTMLDivElement;
    };
    handleClick: (event: React.MouseEvent) => Promise<void>;
    render(): JSX.Element;
}
export type LoadingProps = PropsWithChildren<{}>;
export const Loading: FC<LoadingProps>;
export type CodeBlockProps = PropsWithChildren<{
    language: string;
}>;
export function CodeBlock({ language, children }: CodeBlockProps): JSX.Element;
interface MapExposerProps {
    mapRef: RefCallback<Map>;
}
export type CoordinateValue = `${number}.${number}`;
export interface Location {
    place_id: number;
    osm_id: number;
    osm_type: 'relation';
    boundingbox: [
        CoordinateValue,
        CoordinateValue,
        CoordinateValue,
        CoordinateValue
    ];
    lat: CoordinateValue;
    lon: CoordinateValue;
    display_name: string;
    licence: string;
}
export interface SearchItem extends Location {
    type: 'administrative';
    class: 'boundary';
    icon: number;
    importance: number;
}
export interface ReverseItem extends Location {
    address: Record<'ISO3166-2-lvl4' | 'country_code' | 'country', string> & Partial<Record<'state' | 'state_district' | 'town' | 'village' | 'road' | 'neighbourhood' | 'building' | 'house_number' | 'amenity' | 'postcode', string>>;
}
export type LeafLetComponent = 'TileLayer' | 'Marker';
export type MapEvent<N extends LeafLetComponent> = {
    [K in keyof LeafletEventHandlerFnMap as `on${N}${Capitalize<CamelEventName<K>>}`]: LeafletEventHandlerFnMap[K];
};
export interface MarkerMeta extends Pick<MarkerProps, 'position'> {
    tooltip?: string;
    popup?: string;
}
export interface OpenMapProps extends Pick<MapContainerProps, 'className' | 'style' | 'center' | 'zoom'>, MapEvent<'TileLayer'>, MapEvent<'Marker'>, Partial<MapExposerProps> {
    tileLayerURL?: string;
    attribution?: ReactNode;
    renderTileLayer?: (eventHandlers: LeafletEventHandlerFnMap) => ReactNode;
    markers?: MarkerMeta[];
    title?: string;
    address?: string;
    onChange?: (data: Required<Pick<OpenMapProps, 'title' | 'address'>>) => any;
}
export const OpenMap: FC<OpenMapProps>;
export type VariantColor = Exclude<Color, 'white' | 'muted'>;
export const VariantColors: VariantColor[];
export function text2color(raw: string, excludeColors?: VariantColor[]): VariantColor;
export function animate(name: string): RefCallback<Element>;
